public with sharing class TestTextAnchors {
    
    public void testTextAnchors(){
    	ESignLiveSDK sdk = new ESignLiveSDK();
         
        //Create package
        ESignLiveAPIObjects.Package_x pkg = new ESignLiveAPIObjects.Package_x();
        pkg.name = 'Test Text Anchors - ' + Datetime.now().format();
        pkg.status = ESignLiveAPIObjects.PackageStatus.DRAFT;
        
        //Create Roles
        String roleId1 = 'Signer1';
        ESignLiveAPIObjects.Role role1 = new ESignLiveAPIObjects.Role();
        role1.signers = sdk.createRolesSigner('sigenr1_firstname', 'signer1_lastname', 'signer1@mailinator.com', 'CEO', 'ABC Bank');
        role1.id = roleId1;
        role1.name = roleId1;
        
        String roleId2 = 'Signer2';
        ESignLiveAPIObjects.Role role2 = new ESignLiveAPIObjects.Role();
        role2.signers = sdk.createRolesSigner('sigenr2_firstname', 'signer2_lastname', 'signer2@mailinator.com', 'Applicant', 'ABC Company');
        role2.id = roleId2;
        role2.name = roleId2;
        
        pkg.roles = new List<ESignLiveAPIObjects.Role>{role1, role2};    //add role


        //Prepare Documents Blob
        String document1Name = 'Sample_Text_Anchor';
        StaticResource sr = [SELECT Id, Body FROM StaticResource WHERE Name = 'test_text_anchor' LIMIT 1];
        Map<String,Blob> documentBlobMap = new Map<String,Blob>();
        documentBlobMap.put(document1Name, sr.Body);
         
         
        //Create Document Metadata
        ESignLiveAPIObjects.Document document1 = new ESignLiveAPIObjects.Document();
        document1.name = document1Name;
        document1.id = document1Name;
        document1.extract = true;		//document level extraction:true
        
        
        
        
        //approval for role1
        ESignLiveAPIObjects.Approval approval1 = new ESignLiveAPIObjects.Approval();
        approval1.role = roleId1;
        approval1.id = 'approval1';
        
        
        ESignLiveAPIObjects.Field field11 = new ESignLiveAPIObjects.Field();
        field11.id = 'signature1';
        field11.type = 'SIGNATURE';
        field11.subtype = 'FULLNAME';
        field11.extractAnchor = new ESignLiveAPIObjects.ExtractAnchor(ESignLiveAPIObjects.AnchorPoint.TOPLEFT,0,40,0,0,'Signature of the Client',-50,150); 

		ESignLiveAPIObjects.Field field12 = new ESignLiveAPIObjects.Field();
        field12.id = 'signername1';
        field12.type = 'INPUT';
        field12.subtype = 'LABEL';
        field12.binding = '{signer.name}';	//indicate it's a signer name label
        field12.extractAnchor = new ESignLiveAPIObjects.ExtractAnchor(ESignLiveAPIObjects.AnchorPoint.TOPRIGHT,0,20,0,-175,'(hereafter referred to as',-5,150); 

		ESignLiveAPIObjects.Field field13 = new ESignLiveAPIObjects.Field();
        field13.id = 'signerdate1';
        field13.type = 'INPUT';
        field13.subtype = 'LABEL';
        field13.binding = '{approval.signed}';	//indicate it's a signing date
        field13.extractAnchor = new ESignLiveAPIObjects.ExtractAnchor(ESignLiveAPIObjects.AnchorPoint.TOPRIGHT,4,40,0,10,'Date',-30,75); 

        approval1.fields = new List<ESignLiveAPIObjects.Field>{field11,field12,field13};
        
        
        //approval for role2
        ESignLiveAPIObjects.Approval approval2 = new ESignLiveAPIObjects.Approval();
        approval2.role = roleId2;
        approval2.id = 'approval2';
        
        
        ESignLiveAPIObjects.Field field21 = new ESignLiveAPIObjects.Field();
        field21.id = 'signature2';
        field21.type = 'SIGNATURE';
        field21.subtype = 'FULLNAME';
        field21.extractAnchor = new ESignLiveAPIObjects.ExtractAnchor(ESignLiveAPIObjects.AnchorPoint.TOPLEFT,0,40,0,0,'Signature of the Contractor',-50,150); 

		ESignLiveAPIObjects.Field field22 = new ESignLiveAPIObjects.Field();
        field22.id = 'signername2';
        field22.type = 'INPUT';
        field22.subtype = 'LABEL';
        field22.binding = '{signer.name}';	//indicate it's a signer name label
        field22.extractAnchor = new ESignLiveAPIObjects.ExtractAnchor(ESignLiveAPIObjects.AnchorPoint.TOPRIGHT,0,20,1,-175,'(hereafter referred to as',-5,150); 

		ESignLiveAPIObjects.Field field23 = new ESignLiveAPIObjects.Field();
        field23.id = 'signerdate2';
        field23.type = 'INPUT';
        field23.subtype = 'LABEL';
        field23.binding = '{approval.signed}';	//indicate it's a signing date
        field23.extractAnchor = new ESignLiveAPIObjects.ExtractAnchor(ESignLiveAPIObjects.AnchorPoint.TOPRIGHT,4,40,1,10,'Date',-30,75); 


        approval2.fields = new List<ESignLiveAPIObjects.Field>{field21,field22,field23};
     
        
        document1.approvals = new List<ESignLiveAPIObjects.Approval>{approval1,approval2};
        
        pkg.documents = new List<ESignLiveAPIObjects.Document>{document1};    //add document
        
    	//Send package One Step
        String packageId = sdk.createPackage(pkg,documentBlobMap);
        System.debug('PackageId: ' + packageId);
    }
    
}